namespace efl { 
inline ::efl::eolian::return_traits<void>::type Canvas::pointer_canvas_xy_get( ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y) const
{
   int __out_param_x = {};
   int __out_param_y = {};
    ::efl_canvas_pointer_canvas_xy_get(this->_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<bool>::type Canvas::pointer_inside_get() const
{
   Eina_Bool __return_value =  ::efl_canvas_pointer_inside_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Canvas::image_max_size_get( ::efl::eolian::out_traits<int>::type maxw,  ::efl::eolian::out_traits<int>::type maxh) const
{
   int __out_param_maxw = {};
   int __out_param_maxh = {};
   Eina_Bool __return_value =  ::efl_canvas_image_max_size_get(this->_eo_ptr()
      , & __out_param_maxw
      , & __out_param_maxh);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(maxw, __out_param_maxw);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(maxh, __out_param_maxh);
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Canvas::smart_objects_calculate() const
{
    ::efl_canvas_smart_objects_calculate(this->_eo_ptr());
}
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type Canvas::objects_at_xy_get( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<bool>::type include_pass_events_objects,  ::efl::eolian::in_traits<bool>::type include_hidden_objects) const
{
   Eina_Iterator * __return_value =  ::efl_canvas_objects_at_xy_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_pass_events_objects)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_hidden_objects));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Canvas::object_top_at_xy_get( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<bool>::type include_pass_events_objects,  ::efl::eolian::in_traits<bool>::type include_hidden_objects) const
{
    ::Efl_Gfx* __return_value =  ::efl_canvas_object_top_at_xy_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_pass_events_objects)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_hidden_objects));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type Canvas::objects_in_rectangle_get( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h,  ::efl::eolian::in_traits<bool>::type include_pass_events_objects,  ::efl::eolian::in_traits<bool>::type include_hidden_objects) const
{
   Eina_Iterator * __return_value =  ::efl_canvas_objects_in_rectangle_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_pass_events_objects)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_hidden_objects));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Canvas::object_top_in_rectangle_get( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h,  ::efl::eolian::in_traits<bool>::type include_pass_events_objects,  ::efl::eolian::in_traits<bool>::type include_hidden_objects) const
{
    ::Efl_Gfx* __return_value =  ::efl_canvas_object_top_in_rectangle_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_pass_events_objects)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_hidden_objects));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
} 
namespace eo_cxx {
namespace efl { 
inline ::efl::eolian::return_traits<void>::type Canvas::pointer_canvas_xy_get( ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y) const
{
   int __out_param_x = {};
   int __out_param_y = {};
    ::efl_canvas_pointer_canvas_xy_get(this->_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<bool>::type Canvas::pointer_inside_get() const
{
   Eina_Bool __return_value =  ::efl_canvas_pointer_inside_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Canvas::image_max_size_get( ::efl::eolian::out_traits<int>::type maxw,  ::efl::eolian::out_traits<int>::type maxh) const
{
   int __out_param_maxw = {};
   int __out_param_maxh = {};
   Eina_Bool __return_value =  ::efl_canvas_image_max_size_get(this->_eo_ptr()
      , & __out_param_maxw
      , & __out_param_maxh);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(maxw, __out_param_maxw);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(maxh, __out_param_maxh);
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Canvas::smart_objects_calculate() const
{
    ::efl_canvas_smart_objects_calculate(this->_eo_ptr());
}
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type Canvas::objects_at_xy_get( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<bool>::type include_pass_events_objects,  ::efl::eolian::in_traits<bool>::type include_hidden_objects) const
{
   Eina_Iterator * __return_value =  ::efl_canvas_objects_at_xy_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_pass_events_objects)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_hidden_objects));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Canvas::object_top_at_xy_get( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<bool>::type include_pass_events_objects,  ::efl::eolian::in_traits<bool>::type include_hidden_objects) const
{
    ::Efl_Gfx* __return_value =  ::efl_canvas_object_top_at_xy_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_pass_events_objects)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_hidden_objects));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type Canvas::objects_in_rectangle_get( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h,  ::efl::eolian::in_traits<bool>::type include_pass_events_objects,  ::efl::eolian::in_traits<bool>::type include_hidden_objects) const
{
   Eina_Iterator * __return_value =  ::efl_canvas_objects_in_rectangle_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_pass_events_objects)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_hidden_objects));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Canvas::object_top_in_rectangle_get( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h,  ::efl::eolian::in_traits<bool>::type include_pass_events_objects,  ::efl::eolian::in_traits<bool>::type include_hidden_objects) const
{
    ::Efl_Gfx* __return_value =  ::efl_canvas_object_top_in_rectangle_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_pass_events_objects)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(include_hidden_objects));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
inline efl::Canvas::operator ::efl::Canvas() const { return *static_cast< ::efl::Canvas const*>(static_cast<void const*>(this)); }
inline efl::Canvas::operator ::efl::Canvas&() { return *static_cast< ::efl::Canvas*>(static_cast<void*>(this)); }
inline efl::Canvas::operator ::efl::Canvas const&() const { return *static_cast< ::efl::Canvas const*>(static_cast<void const*>(this)); }
} }

